@@ -284,7 +284,6 @@
     </message>
     <message>
         <location filename="../main.cpp" line="100"/>
-        <location filename="../main.cpp" line="124"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
@@ -294,12 +293,11 @@
         <translation>Не удалось найти conky-manager, пожалуйста установите его до запуска mx-conky</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="125"/>
         <source>No file was selected, quiting program</source>
-        <translation>Не выбрано файла, программа закрывается</translation>
+        <translation type="vanished">Не выбрано файла, программа закрывается</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="136"/>
+        <location filename="../main.cpp" line="134"/>
         <source>You must run this program as normal user</source>
         <translation>Вы должны запускать приложение под обычным пользователем</translation>
     </message>
